#
# spec file for package lxqt-globalkeys
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-globalkeys
Version:        2.1.0
Release:        1.3
Summary:        Global keyboard shortcuts registration
License:        LGPL-2.1-or-later
URL:            https://github.com/lxqt/lxqt-globalkeys
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.18.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6WindowSystem) >= 6.0.0
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6LinguistTools) >= 6.6
BuildRequires:  cmake(Qt6Widgets) >= 6.6
BuildRequires:  cmake(lxqt) >= %{version}
BuildRequires:  cmake(lxqt2-build-tools) >= 2.1.0
Requires:       %{name}-branding = %{version}-%{release}

%description
Daemon and library for global keyboard shortcuts registration

%lang_package

%package devel
Summary:        Development files for lxqt-globalkeys
Requires:       %{name} = %{version}
Requires:       liblxqt-globalkeys-ui2 = %{version}
Requires:       liblxqt-globalkeys2 = %{version}
Requires:       pkgconfig

%description devel
Development files for lxqt-globalkeys including headers and libraries

%package -n liblxqt-globalkeys2
Summary:        Lxqt-globalkeys libraries
# liblxqt-globalkeys0 already contained a file liblxqt-globalkeys.so.1.0.0 by mistake
Conflicts:      liblxqt-globalkeys1
Conflicts:      liblxqt-globalkeys0

%description -n liblxqt-globalkeys2
lxqt-globalkeys main system library

%package -n liblxqt-globalkeys-ui2
Summary:        UI lxqt-globalkeys libraries
# liblxqt-globalkeys-ui0 already contained a file liblxqt-globalkeys-ui.so.1.0.0 by mistake
Conflicts:      liblxqt-globalkeys-ui0
Conflicts:      liblxqt-globalkeys-ui1

%description -n liblxqt-globalkeys-ui2
UI system libraries for lxqt-globalkeys

%package branding-upstream
Summary:        Upstream branding of %{name}
Group:          System/GUI/LXQt
Requires:       %{name} = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for %{name}.

%prep
%autosetup -p1
# Changing LXQt into X-LXQt in desktop files to be freedesktop compliant and shut rpmlint warnings
#find -name '*desktop.in*' -exec sed -ri 's/(LXQt;)/X-\1/' {} +

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}
%fdupes -s %{buildroot}
install -Dm 0644 %{buildroot}%{_datadir}/lxqt/globalkeyshortcuts.conf -t %{buildroot}%{_sysconfdir}/xdg/lxqt/

%find_lang lxqt-config-globalkeyshortcuts --with-qt

%ldconfig_scriptlets -n liblxqt-globalkeys2
%ldconfig_scriptlets -n liblxqt-globalkeys-ui2

%files
%license LICENSE
%doc AUTHORS
%{_bindir}/lxqt-globalkeysd
%{_bindir}/lxqt-config-globalkeyshortcuts
%{_datadir}/applications/lxqt-config-globalkeyshortcuts.desktop
%config %{_sysconfdir}/xdg/autostart/lxqt-globalkeyshortcuts.desktop
%{_datadir}/lxqt/globalkeyshortcuts.conf

%files devel
%{_includedir}/%{name}
%{_includedir}/lxqt-globalkeys-ui
%{_qt6_libdir}/pkgconfig/*.pc
%{_qt6_libdir}/liblxqt-globalkeys.so
%{_qt6_libdir}/liblxqt-globalkeys-ui.so
%dir %{_datadir}/cmake/lxqt-globalkeys
%dir %{_datadir}/cmake/lxqt-globalkeys-ui
%{_datadir}/cmake/lxqt-globalkeys/*
%{_datadir}/cmake/lxqt-globalkeys-ui/*

%files -n liblxqt-globalkeys2
%{_qt6_libdir}/liblxqt-globalkeys.so.2*

%files -n liblxqt-globalkeys-ui2
%{_qt6_libdir}/liblxqt-globalkeys-ui.so.2*

%files branding-upstream
%dir %{_sysconfdir}/xdg/lxqt/
%config %{_sysconfdir}/xdg/lxqt/globalkeyshortcuts.conf

%files lang -f lxqt-config-globalkeyshortcuts.lang
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%{_datadir}/lxqt/translations/lxqt-config-globalkeyshortcuts

%changelog
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#311)
  * Weblate commits (#313)
  * Weblate commits (#312)
  * Updated translations (incl. Luganda) (#310)
  * Weblate commits (#309)
  * Weblate commits (#308)
  * Weblate commits (#307)
  * Weblate commits (#306)
  * Weblate commits (#305)
  * Add icons to dialog buttons (#298)
* Thu Apr 18 2024 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6
- Specfile cleanup, and macro updating
* Sun Nov  5 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0
  * Removed KWindowSystem as a direct dependency (liblxqt already
    brings KWindowSystem in as an INTERFACE_LINK dependency).
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Translations are updated
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Updated translations and bumped the version.
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Update translations
* Fri Jan  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.0.1:
  * The asynchronous behavior of Xlib is kept intact. It
    guarantees that the global shortcut daemon starts correctly
    with the session after a change in the behavior of
    libx11 1.7.3.1.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Added shortcut filtering and did some code cleanup.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Made the code cleaner and more up-to-date.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Added shortcut to configure display.
  * Silenced unused function parameters warnings.
  * Do not grab keys of disabled client actions.
  * Do not requite daemon restart for enabling shortcuts.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-globalkeys.keyring to tsujan's key
* Fri Apr 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Removed lxqt-globalkeys-0.14.1-fix-qt.5.14.patch: contained in upstream
- Update to version 0.15.0
  * Just some code cleanups are done.
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Add lxqt-globalkeys-0.14.1-fix-qt.5.14.patch
* Thu Oct 17 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.3:
  * In write_basic_package_version_file use the right package version
* Fri Oct 11 2019 mvetter@suse.com
- Update to 0.14.2:
  * Better handling of default shortcuts
  * gui: Prevent exactly the same shortcut from being repeated at startup
  * gui: Remember config window size on exiting
  * gui: Better column widths with single-line texts
  * daemon: Use XDG hierarchy if no config file given
  * daemon: move shortcuts config fom /etc/xdg/lxqt to /usr/share/lxqt
  * daemon: Fixed loading of settings
  * cmake: Enhances Qt minimum required versions handling
  * cmake: Matches lxqt-globalkeys/ui required versions
  * cmake: Updates self version handling
  * Port towards C++ headers
  * Port towards C++11 override
  * Port towards C++11 nullptr
  * Updated translations
* Mon Feb 25 2019 mvetter@suse.com
- Update to 0.14.1:
  * Don't rename a widget or a class without a full refactoring
  * Updated translations
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Don't use automatic string conversions
  * Improved cmake scripting
  - Set cmake_minimum_required to 3.1.0
  - Removed locale compile definitons
  - Remove QUIET from find_package
  * Moved translations from lxqt-l10n back to lxqt-globalkeys
  - Removed obsolete translation fuctionality
  - Added translation promo in README.md
  * Deleted superfluous *cs_CZ.desktop files
  * Translation updates
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * Triggering shortcuts with meta keys
  * Register meta keys for shortcuts
  * Daemon triggers on KeyRelease
  * Avoid polluting the the x11 shortcut map.
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * Don't export github templates
  * fix deadlock - don't accept keyPress when processing dbus call (#56)
  * Added Lithuanian language
  * lxqt-config-globalkeys: set Qt::AA_UseHighDpiPixmaps to true
  * Added QCommandLineParser and basic cli interface to lxqt-config-globalkeys
  * Adeed LXQT_GLOBALKEYS_PATCH_VERSION
  * Fixes a FTBFS in superbuild mode (#51)
  * Added autostart and xdg to CMakeLists.txt
  * changed xdg/CmakeLists.txt
  * fixed xdg/CMakeLists.txt renamed config to xdg - merge preparation
  * Use const iterators
  * globalkeys: Open "empty" browser on activation
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * Update AUTHORS
  * Open https://duckduckgo.com instead of google.com as default
  * Update desktop entries and Replace fr_FR by fr
  * lxqt-rc.xml: Change default config install path
  * Settings Openbox updated.
  * Screenshot (Shift+Print), file manager (ctl+Alt+e) and web browser (Ctl+atl+i) key shortcuts added.
  * Default key shortcuts added to lxqt-globalkeysd.
  * Update Greek translation (el) Remove country variant from language code
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Adds double quotes to everything that may break
  * Updates the build system to use the Targets infrastructure
  * Drops hardcoded /etc/xdg paths
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Add session.conf and windowmanagers.conf.
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Rename dirs and replace razor with lxqt. Install lxqt.conf to /etc/xdg/lxqt and provide theme config.
  * Properly set default wallpaper for pcmanfm-qt. Comment out openbox config handling in startlxde-qt since it's not needed.
  * Fix file paths, replacing razor with lxqt. * Remove Alt+F2 and Ctrl+Esc from openbox config file to avoid conflicts with lxqt-panel & lxqt-globalkeys.
  * Add default configuration files for lxde-qt session.
- Remove post and postun
* Thu Feb 23 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Added *da.desktop
  * Use the lxqt-build-tools/lxqt_create_portable_headers
  * Use the new lxqt-build-tools package
  * Create lxqt-config-globalkeyshortcuts_fr.desktop
  * Remove cpack (#41)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Add README.md
  * Add Catalan translation
  * daemon: Use QDBusServiceWatcher
  * Fix typo in German translation for desktop file (#38)
  * build: Use external translations
  * ts-files removal (#35)
  * Improve foreach iterator use
  * daemon/core: Optimize Core startup string stuff
  * Client: Fix memory leak (static data)
  * Fix untranslated string in French translation
  * fix reseting the state of the edit dialog
  * Default configs from /etc/xdg/lxqt must be loaded.
  * static_cast<error_t>, fixes FTBFS for the Hurd
  * lxqt-globalkeys is LGPL only, there are no GPL files in it
  * Update italian translation, remove country-specific variant
  * Italian translation update
  * Update Russian translation Remove ru_RU files
  * Update French translation
  * client: Fix typo in pkg-config dependencies
  * upd: lxqt-config-globalkeyshortcuts_hu.ts
  * Fix warning
- Add keyring
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
- Removing patches:
  * fix_desktop_categories.patch - Using sed in spec file now
* Fri Feb 20 2015 sfalken@opensuse.org
- Updated %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Added Patch
  + fix_desktop_categories.patch
- Dropped -qt5 package naming, as none of the internal library
  names use -qt5 in 0.9.0.  Added Obsoletes and Conflicts, in the
  odd chance that lxqt-globalkeys-0.7.0 and lxqt-globalkeys >=0.8.0
  are installed on the same system.  Which should never happen.
  lxqt-0.9.0 is not likely to be pushed to 13.2, and liblxqt can no
  longer be built against Qt4.
* Tue Feb  3 2015 dvaleev@suse.com
- aarch64 ppc64 ppc64le have /usr/lib64 too
* Sun Jan 25 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- spec file working - split out libraries subpackages
* Tue May 13 2014 sfalken@opensuse.org
- Specfile Cleanup
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora specfile, split into subproject
  Del:  lxqt-globalkeys-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-globalkeys-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-globalkeys-0.7.0.tar.xz
  Del:  _service
* Wed Apr  2 2014 sfalken@opensuse.org
- Removed direct cmake calls, in favour of %%cmake and %%cmake_install
* Wed Apr  2 2014 sfalken@opensuse.org
- Removed patch, as it didn't accomplish the desired effect
  Deleted: 0001_lxqt_globalkey_desktop.patch
* Wed Apr  2 2014 sfalken@opensuse.org
- Added patch to correct .desktop file
  Add: 0001_lxqt_globalkey_desktop.patch
* Wed Apr  2 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-globalkeys.spec
  Add: lxqt-globalkeys.changes
